/* This file is part of the Imote2 Codeloader.
 *
 * The Imote2 Codeloader is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Imote2 Codeloader is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the Imote2 Codeloader. If not, see <http://www.gnu.org/licenses/>.
*/
/**
 * ImoteDescription.java
 *
 * @author Markus Engel
 * Copyright (c) 2009,2010 Networked Systems Group, University of Kaiserslautern
 */

package imote;

/** Describes a connected Imote
 *
 * @author m_engel
 */
public class ImoteDescription {
	/** serial number and node id */
	private final ImoteSerial serial;
	/** version of bootloader */
	private final String version;

	/** setup new description
	 *
	 * @param serial serial number and node id
	 * @param version version of bootloader
	 */
	public ImoteDescription(ImoteSerial serial, String version) {
		this.serial = serial;
		this.version = version;
	}

	/** get serial number and node id
	 *
	 * @return serial number and node id
	 */
	public ImoteSerial getSerial() {
		return this.serial;
	}

	/** get version of bootloader
	 *
	 * @return bootloader version
	 */
	public String getVersion() {
		return this.version;
	}
}
